==> haskell-mmorph-1.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mmorph.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mmorph
version: 1.1.1
id: mmorph-1.1.1-JSXAlwXaEvB9wEd1iGFnPP
key: mmorph-1.1.1-JSXAlwXaEvB9wEd1iGFnPP
license: BSD3
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Monad morphisms
description:
    This library provides monad morphism utilities, most commonly used
    for manipulating monad transformer stacks.
category: Control
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Morph Control.Monad.Trans.Compose
abi: 95d13a4e892cac98ce59ec611b08550c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mmorph-1.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/mmorph-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mmorph-1.1.1
hs-libraries: HSmmorph-1.1.1-JSXAlwXaEvB9wEd1iGFnPP
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
haddock-interfaces: /usr/share/doc/haskell-mmorph/html/mmorph.haddock
haddock-html: /usr/share/doc/haskell-mmorph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmorph-1.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mmorph.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mmorph
version: 1.1.2
id: mmorph-1.1.2-KKZMr2x9eQv4KwETGEYeu
key: mmorph-1.1.2-KKZMr2x9eQv4KwETGEYeu
license: BSD3
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Monad morphisms
description:
    This library provides monad morphism utilities, most commonly used
    for manipulating monad transformer stacks.
category: Control
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Morph Control.Monad.Trans.Compose
abi: 5fa90a74e8da06f2ac014a5b11b06a5b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mmorph-1.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/mmorph-1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mmorph-1.1.2
hs-libraries: HSmmorph-1.1.2-KKZMr2x9eQv4KwETGEYeu
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
haddock-interfaces: /usr/share/doc/haskell-mmorph/html/mmorph.haddock
haddock-html: /usr/share/doc/haskell-mmorph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
